from django.shortcuts import render_to_response
from django.template import RequestContext
from django.conf import settings

from djcelery.models import WorkerState, TaskState
from lava_server.views import index as lava_index
from lava_server.bread_crumbs import (
    BreadCrumb,
    BreadCrumbTrail,
)


@BreadCrumb("Celery", parent=lava_index)
def index(request):
    return render_to_response(
        "lava/celery/index.html", {
            'BROKER_HOST': settings.BROKER_HOST,
            'BROKER_PORT': settings.BROKER_PORT,
            'BROKER_USER': settings.BROKER_USER,
            'BROKER_VHOST': settings.BROKER_VHOST,
            'CELERYD_CONCURRENCY': settings.CELERYD_CONCURRENCY,
            'CELERYD_PREFETCH_MULTIPLIER': settings.CELERYD_PREFETCH_MULTIPLIER,
            'CELERY_RESULT_BACKEND': settings.CELERY_RESULT_BACKEND,
            'CELERY_RESULT_PERSISTENT': settings.CELERY_RESULT_PERSISTENT,
            'worker_state_list': WorkerState.objects.all(),
            'task_state_list': TaskState.objects.all().filter(state__in=('STARTED', 'PENDING', 'RETRY')),
            'bread_crumb_trail': BreadCrumbTrail.leading_to(index)
        }, RequestContext(request))



import os

from lava_server.extension import LavaServerExtension


class CeleryExtension(LavaServerExtension):

    @property
    def app_name(self):
        return "lava.celery"

    @property
    def name(self):
        return "Celery"

    @property
    def main_view_name(self):
        return "lava.celery.views.index"

    @property
    def description(self):
        return "Celery Integration"

    @property
    def version(self):
        import lava.celery
        import versiontools
        return versiontools.format_version(lava.celery.__version__, lava.celery)

    def contribute_to_settings(self, settings_module):
        super(CeleryExtension, self).contribute_to_settings(settings_module)
        settings_module['INSTALLED_APPS'].extend([
            "djcelery",
        ])
        settings_module.update({
            'BROKER_HOST': '127.0.0.1',
            'BROKER_PORT': 5672,
            'BROKER_USER': 'guest',
            'BROKER_PASSWORD': 'guest',
            'BROKER_VHOST': '/'
        })
        import djcelery
        djcelery.setup_loader()

    def contribute_to_settings_ex(self, settings_module, settings_object):
        settings_module.update({
            # We want to automatically determine the number of workers
            "CELERYD_CONCURRENCY": settings_object.get_setting("CELERYD_CONCURRENCY", None),
            # We want to prefetch at most one task, this is better as lava prefers long running tasks
            "CELERYD_PREFETCH_MULTIPLIER": settings_object.get_setting("CELERYD_PREFETCH_MULTIPLIER", 1),
            # We want to send results back as amqp messages
            "CELERY_RESULT_BACKEND": settings_object.get_setting("CELERY_RESULT_BACKEND", "amqp"),
            # We want persistent tasks by default (survive broker restarts)
            "CELERY_RESULT_PERSISTENT": settings_object.get_setting("CELERY_RESULT_PERSISTENT", True),
            # Broker configuration
            'BROKER_HOST': settings_object.get_setting("BROKER_HOST", '127.0.0.1'),
            'BROKER_PORT': settings_object.get_setting("BROKER_PORT", 5672),
            'BROKER_USER': settings_object.get_setting("BROKER_USER", 'guest'),
            'BROKER_PASSWORD': settings_object.get_setting("BROKER_PASSWORD", 'guest'),
            'BROKER_VHOST': settings_object.get_setting("BROKER_VHOST", '/'),
        })



#!/usr/bin/env python

from setuptools import setup, find_packages


setup(
    name='lava-celery',
    version=":versiontools:lava.celery:",
    author="Zygmunt Krynicki",
    author_email="zygmunt.krynicki@linaro.org",
    namespace_packages=['lava'],
    packages=find_packages(),
    license="AGPL",
    description="Celery integration for LAVA Server",
    entry_points="""
    [lava_server.extensions]
    celery=lava.celery.extension:CeleryExtension
    """,
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
    ],
    install_requires=[
        'lava-server >= 0.2.1',
        'versiontools >= 1.8',
        'django-celery',
    ],
    setup_requires=[
        'versiontools >= 1.8',
    ],
    zip_safe=False,
    include_package_data=True
)

